QList, Lazy, EagerQList
### take_while
[x] [x] [x] implemented \
[x] [x] [x] documented \
[x] [x] [x] tested

### all
[x] [x] [x] implemented \
[x] [x] [x] documented \
[x] [x] [x] tested

### any
[x] [x] [x] implemented \
[x] [x] [x] documented \
[x] [x] [x] tested

### scan
[x] [x] [x] implemented \
[x] [x] [x] documented \
[x] [x] [x] tested

### min
[x] [x] [x] implemented \
[x] [x] [x] documented \
[x] [x] [x] tested

### max
[x] [x] [x] implemented \
[x] [x] [x] documented \
[x] [x] [x] tested

### sum
[x] [x] [x] implemented \
[x] [x] [x] documented \
[x] [x] [x] tested

### full_flatten
[x] [x] [x] implemented \
[x] [x] [x] documented \
[x] [x] [x] tested

### merge
[x] [x] [x] implemented \
[x] [x] [x] documented \
[x] [x] [x] tested

### chain
[x] [x] [x] implemented \
[x] [x] [x] documented \
[x] [x] [x] tested

### batch
[x] [x] [x] implemented \
[x] [x] [x] documented \
[x] [x] [x] tested

### batch_by
[x] [x] [x] implemented \
[x] [x] [x] documented \
[x] [x] [x] tested

### window
[x] [x] [x] implemented \
[x] [x] [x] documented \
[x] [x] [x] tested

### iter
[x] [x] [x] implemented \
[x] [x] [x] documented \
[x] [x] [x] tested

w assertach jest res == expected kolejność